function [argout1, argout2] = plotinit(argin1, argin2)

% INIT     Part of the NVODS data browser.
%
%         Xin Zhang  U. of Rhode Island, Nov. 30 2002
%         zhangxin@ele.uri.edu
%
% This file is used to initialize the parameters of slice and
% slicesize in X-data,Y-data,Z-data(U-data) and V-data
% for display_choices corresponding to different plot
% type(Plot,Imagesc,Contour,Contourf,Pcolor,Quiver,Polar)

% shared with other programs
global combo_display_data display_choices
global all_display_data all_display_metadata

% Standardized input arguments, 2003/07/05.  This program no longer
% interacts directly with the display_menu in any way, which is as
% should be.  dbyrne 2003/07/07
if nargin < 2
  disp('usage: plotinit(mode, whichplot)')
  return
end
mode = argin1;
plotno = argin2;
acqno = display_choices(plotno).acqno;
acqchoices = cat(1,all_display_data(:).acqno);
acqindex = find(acqchoices == acqno);
dods_err = 0;
dods_err_msg = '';
argout1 = [];
argout2 = [];
if length(acqindex) > 1
  % we're in trouble!  There are overlapping Rxx numbers
  % from different downloads
  dods_err = 1;
  dods_err_msg = ['Fatal error.  Please clear all acquired data and', ...
	   ' repeat your most recent data request.'];
  % now stuff these into the output arguments
  argout1 = dods_err;
  argout2 = dods_err_msg;
  return
end

index = all_display_data(acqindex).index;
geopos = all_display_metadata{index}.geopos;
if sum(geopos > 0) == 0
  % OVERRIDE: try and find geoposition variables by names
  % rather than using the metadata axis info.
  geopos = zeros(1,4);
  geonames = [{'Longitude'};{'Latitude'}; {'Depth'}'; {'Time'}];
  names = cellstr(all_display_data(acqindex).name);
  for i = 1:length(geonames)
    for j = 1:length(names)
      if instr(geonames{i}, names{j})
	geopos(i) = 1;
      end
    end
  end
end
      

if display_choices(plotno).all_flag  % if all_flag is 1
  for i = 1:size(combo_display_data.name,1)
    if ~isempty(instr(deblank(combo_display_data.name(i,:)), ...
	  display_choices(plotno).x_slice))
      display_choices(plotno).x = i;
    elseif ~isempty(instr(deblank(combo_display_data.name(i,:)), ...
	  display_choices(plotno).y_slice))
      display_choices(plotno).y = i;
    end
  end
end

switch mode
  case 'initial'
    % try to guess what kind of plot should be selected
    [U_flag, V_flag] = plotinit('uvflags', plotno);
      
    if ~isempty(U_flag) & ~isempty(V_flag) % Both U and V exist
      display_choices(plotno).plot_type = 'quiver';
      % set U and V as default U-data and V-data
      setdispchoice('z',all_display_data(acqindex).name(U_flag,:),plotno);
      setdispchoice('zz',all_display_data(acqindex).name(V_flag,:),plotno);
    else  % No U and V
      % find the first getvariable in display_data.names
      getvariables = cellstr(all_display_data(acqindex).getvariables);
      names = cellstr(all_display_data(acqindex).name);
      varname = '';
      for ii = 1:length(getvariables)
	for j = 1:length(names)
	  k = instr(getvariables{ii},names{j});
	  if ~isempty(k)
	    varname = names{j};
	    break
	  end
	end
      end
      setdispchoice('z',varname,plotno);
      setdispchoice('zz',varname,plotno);
    end  % end of chosing quiver or leaving with default
    
    % Now to setup the initial default of plotting axes
    if sum(geopos > 0) > 1
      % This is for Imagesc or Quiver default
      plotinit('setimageaxes', plotno);
    elseif sum(geopos > 0) == 1
      % set up plotting defaults
      display_choices(plotno).marker = '.';
      display_choices(plotno).linestyle = '-';
      display_choices(plotno).color = 'k';
      display_choices(plotno).plot_type = 'plot';
      plotinit('setplotaxes', plotno);
    end
      
  case 'imagemode'
    if display_choices(plotno).all_flag
      for i = 1:size(combo_display_data.name,1)
	if ~isempty(instr(deblank(combo_display_data.name(i,:)), ...
			  display_choices(plotno).z_slice))
	  display_choices(plotno).z = i;
	end
      end
    end

    % find the first getvariable in display_data.names
    getvariables = cellstr(all_display_data(acqindex).getvariables);
    names = cellstr(all_display_data(acqindex).name);
    varname = '';
    for i = 1:length(getvariables)
      for j = 1:length(names)
	k = instr(getvariables{i},names{j});
	if ~isempty(k)
	  varname = names{j};
	  break
	end
      end
    end
    setdispchoice('z',varname,plotno);
    
    % Now to setup the initial default of plotting axes
    if sum(geopos > 0) > 1
      % This is for Imagesc or Quiver default
      plotinit('setimageaxes', plotno);
    end
    
  case 'quivermode'
    if display_choices(plotno).all_flag
      for i = 1:size(combo_display_data.name,1)
	if ~isempty(instr(deblank(combo_display_data.name(i,:)), ...
			  display_choices(plotno).z_slice))
	  display_choices(plotno).z = i;
	elseif ~isempty(instr(deblank(combo_display_data.name(i,:)), ...
			      display_choices(plotno).zz_slice))
	  display_choices(plotno).zz = i;
	end
      end
      
      return
    end
    
    % This is the original codes by Deirdre, there is a bug here. If you
    % would like to run quiver, the default slice
    % in U-data and V-data listbox should be Rx_XXX_U and Rx_XXX_V.
    % This following codes work when there are only two
    % matrices with the size of m*n*p, where the size the Latitude is
    % m*1, the size of the Longitude is n*1 and
    % the size of time is p*1, and these two matrices are Rx_XXX_U and
    % Rx_XXX_V
    % However, if you choose variables including Air Temp or Pressure
    % not just XXX_U and XXX_V from the NVODS Variables
    % window, you will find the size of Rx_Air_Temp and Rx_Pressure are
    % also m*n*p, at this time, the following codes
    % will give the wrong result.   By Xin Zhang Oct. 30 2002
    
    % First set Z-data (U-data) and ZZ-data (V-data)
    [U_flag, V_flag] = plotinit('uvflags', plotno);
    
    if ~isempty(U_flag) & ~isempty(V_flag) % Both U and V exist
      % set U and V as default U-data and V-data
      setdispchoice('z',all_display_data(acqindex).name(U_flag,:),plotno);
      setdispchoice('zz',all_display_data(acqindex).name(V_flag,:),plotno);
    elseif ~isempty(U_flag)
      % set U as default U-data
      setdispchoice('z',all_display_data(acqindex).name(U_flag,:),plotno);
      % find the first getvariable in display_data.names
      getvariables = cellstr(all_display_data(acqindex).getvariables);
      names = cellstr(all_display_data(acqindex).name);
      varname = '';
      for ii = 1:length(getvariables)
	for j = 1:length(names)
	  k = instr(getvariables{ii},names{j});
	  if ~isempty(k)
	    varname = names{j};
	    break
	  end
	end
      end
      setdispchoice('zz', varname, plotno);
    elseif ~isempty(V_flag)
      % set V as default V-data
      setdispchoice('zz',all_display_data(acqindex).name(V_flag,:),plotno);
      % find the first getvariable in display_data.names
      getvariables = cellstr(all_display_data(acqindex).getvariables);
      names = cellstr(all_display_data(acqindex).name);
      varname = '';
      for ii = 1:length(getvariables)
	for j = 1:length(names)
	  k = instr(getvariables{ii},names{j});
	  if ~isempty(k)
	    varname = names{j};
	    break
	  end
	end
      end
      setdispchoice('z', varname, plotno);
    else
      % find the first two getvariables in display_data.names
      getvariables = cellstr(all_display_data(acqindex).getvariables);
      names = cellstr(all_display_data(acqindex).name);
      varname = {''};
      for ii = 1:length(getvariables)
	for j = 1:length(names)
	  k = instr(getvariables{ii},names{j});
	  if ~isempty(k)
	    varname = [varname; names(j)];
	    if size(varname,1) == 2
	      break
	    end
	  end
	end
      end
      setdispchoice('z', varname{1}, plotno);
      setdispchoice('zz', varname{2}, plotno);
    end  % end of chosing quiver variables
    
    % Now set up the initial default of plotting axes
    if sum(geopos > 0) > 1
      % This is for Imagesc or Quiver default
      plotinit('setimageaxes', plotno);
    end

  case 'plotmode'
    if display_choices(plotno).all_flag
      % nothing to do
      return
    end
    
    % find the first getvariable in display_data.names
    getvariables = cellstr(all_display_data(acqindex).getvariables);
    names = cellstr(all_display_data(acqindex).name);
    varname = '';
    for ii = 1:length(getvariables)
      for j = 1:length(names)
	k = instr(getvariables{ii},names{j});
	if ~isempty(k)
	  varname = names{j};
	  break
	end
      end
    end
    setdispchoice('z',varname,plotno);
    
    % Now to setup the initial default of plotting axes
    if sum(geopos > 0) == 1
      % This is for Plot
      plotinit('setplotaxes', plotno);
    end
    
  case 'setimageaxes'
    % Now set up the initial default of display_choices.x and .y for Image
    if all(geopos(1:2) > 0)
      % if both lon and lat present choose lon in x, lat in y
      setdispchoice('x','Longitude',plotno);
      setdispchoice('y','Latitude',plotno);
      % set default figure to browse_fig
      display_choices(plotno).figure = 'browse_fig';
    elseif all(geopos(3:4) > 0)
      % if depth and time present
      if geopos(2) > 0  % if Lat present
	setdispchoice('x','Latitude',plotno);
	setdispchoice('y','Depth',plotno);
      elseif geopos(1) > 0  % if Lon present
	setdispchoice('x','Longitude',plotno);
	setdispchoice('y','Depth',plotno);
      else
	setdispchoice('x','Time',plotno);
	setdispchoice('y','Depth',plotno);
      end
    elseif geopos(2) > 0
      % if Lat present and no Lon
      if geopos(3) > 0  % if Depth present and no Time
	setdispchoice('x','Latitude',plotno);
	setdispchoice('y','Depth',plotno);
      else % Time present and no Depth
	setdispchoice('x','Time',plotno);
	setdispchoice('y','Latitude',plotno);
      end
    elseif geopos(1) > 0
      % if Lon present and no Lat
      if geopos(3) > 0  % if Depth present and no Time
	setdispchoice('x','Longitude',plotno);
	setdispchoice('y','Depth',plotno);
      else % Time present and no Depth
	setdispchoice('x','Time',plotno);
	setdispchoice('y','Longitude',plotno);
      end
    end
      
  case 'setplotaxes'
    % Now set up the initial default of display_choices.x and .y for Plot
    if sum(geopos > 0) == 1  % Only one of Lon, Lat, Depth or Time exists
      if geopos(3) > 0   % If Depth exists
	setdispchoice('y','Depth',plotno);
	display_choices(plotno).x = display_choices(plotno).z;
	display_choices(plotno).x_slice = display_choices(plotno).z_slice;
	display_choices(plotno).x_slicesize = display_choices(plotno).z_slicesize;
      else  % No Depth
	display_choices(plotno).y = display_choices(plotno).z;
	display_choices(plotno).y_slice = display_choices(plotno).z_slice;
	display_choices(plotno).y_slicesize = display_choices(plotno).z_slicesize;
	if geopos(2) > 0  % if Lat exists
	  setdispchoice('x','Latitude',plotno);
	elseif geopos(1) > 0 % if Lon exists
	  setdispchoice('x','Longitude',plotno);
	else % if Time exists
	  setdispchoice('x','Time',plotno);
	end
      end
    end
    
  case 'uvflags'
    U_flag = []; V_flag = [];
    names = all_display_data(acqindex).name;
    for i = 1:size(names,1)
      match = strfind(names(i,:),'_U');
      if ~isempty(match)
	U_flag = i;
	break
      end
    end
    if isempty(U_flag)
      for i = 1:size(names,1)
	match = strfind(names(i,:),'U_');
	if ~isempty(match)
	  U_flag = i;
	  break
	end
      end
    end
      
    for i = 1:size(names,1)
      match = strfind(names(i,:),'_V');
      if ~isempty(match)
	V_flag = i;
	break
      end
    end
    if isempty(V_flag)
      for i = 1:size(names,1)
	match = strfind(names(i,:),'V_');
	if ~isempty(match)
	  V_flag = i;
	  break
	end
      end
    end
    argout1 = U_flag;
    argout2 = V_flag;
    
end  % end of switch-case
